# This is free and unencumbered software released into the public domain.

"""Lemberg.AI Software Development Kit (SDK) for Python."""

import sys

assert sys.version_info >= (3, 6), "Lemberg.AI SDK requires Python 3.6+"

__all__ = []
